<?php
/**
 * Melscrivi Module
 *
 *  @author    Webgarh <sudhir@cwebconsultants.com>
 *  @copyright Webgarh
 *  @license   http://cwebconsultants.com
 */

include_once(dirname(__FILE__) . '/../../config/config.inc.php');
class MelascriviPlugin
{

    const PLUGIN_NAME = "melascrivi";
    const PLUGIN_VERSION= "0.0.1";
    const  API_PATH_DEV="http://dev.melascrivi.com/soap/editor_dev.wsdl";
    const SERVER_PATH_DEV="http://dev.melascrivi.com";

    const  API_PATH_IT="http://app.melascrivi.com/soap/editor_it.wsdl";
    const SERVER_PATH_IT="http://app.melascrivi.com";

    const  API_PATH_EN="http://app.hotype.co.uk/soap/editor_uk.wsdl";
    const SERVER_PATH_EN="http://app.hotype.co.uk";

    private $client;

    public function getName()
    {
        return self::PLUGIN_NAME;
    }

    public function getVersion()
    {
        return self::PLUGIN_VERSION;
    }

    public function __construct()
    {
        $this->client= $this->getClient();
    }

    public function __destruct()
    {
        unset($this->client);
    }

    private function getServerPath()
    {
        $website='it';
        switch ($website) {
            case "it":
                return self::SERVER_PATH_IT;
            case "uk":
                return self::SERVER_PATH_EN;
            case "dev":
                return self::SERVER_PATH_DEV;
            default:
                return "";
        }
    }

    public function login($user, $pass)
    {
        $context = Context::getContext();
        unset($context->cookie->credential);
        $response=$this->client->login($user, $pass);
        $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
        return $response;
    }

    protected function getClient()
    {
        $website='it';
        switch ($website) {
            case "it":
                return new SoapClient(self::API_PATH_IT, array('trace' => 1));
            case "uk":
                return new SoapClient(self::API_PATH_EN, array('trace' => 1));
            case "dev":
                return new SoapClient(self::API_PATH_DEV, array('trace' => 1));
            default:
                return null;
        }
    }

    public function requestOrder($userId, $products, $iso_code)
    {
        $context = Context::getContext();
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $ordersArray=array();
        $project_type='';
        foreach ($products as $p) {
            $project_type=$p['project_type'];
            $order=new stdClass();
            $order->project->id=$p['api_project_id'];
            $order->qualityId='0';
            $order->id=$p['product_id'];
            if ($p['project_type']=='Copy') {
                $order->name=$p['project_name'];
                $order->title=$p['name'];
                $order->guideline->id='p'.$p['api_guideline_id'];
                $order->language=$iso_code;
            }
            if ($p['project_type']=='Translation') {
                $date=str_replace("/", "-", $p['t_delivery_date']);
                $words=str_word_count($p['name'])+str_word_count(strip_tags($p['description']));
                $order->userId=$userId;
                $order->name=$p['name'];
                $order->title=$p['name'];
                $order->guideline->maxWords=$words;
                $order->description=html_entity_decode(strip_tags($p['description']));
                $order->language=$p['t_language_from'].','.$p['t_language_to'];
                $order->toTranslate=html_entity_decode(strip_tags($p['description']));
                $order->deadline=date("Y-m-d", strtotime($date)).' 00:00:00';
            }
            $order->circle='1';
            $ordersArray[]=$order;
        }
        $orders=new stdClass();
        $orders->order=$ordersArray;
        $orders->totals=count($products);
        $orders->displayed='1';
        if ($project_type=='Copy') {
            $response=$this->client->createOrder($orders, $userId);
            @$this->client->__setCookie("credential", $context->cookie->credential);
            $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
            return $response;
        } else {
            $response=$this->client->createTranslationOrder($orders, $userId);
            @$this->client->__setCookie("credential", $context->cookie->credential);
            $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
            return $response;
        }
    }

    public function createProject($userId, $projectName, $iso_code)
    {
        $context = Context::getContext();
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $project=new stdClass();
        $project->name=$projectName;
        $project->language=$iso_code;
        $response=$this->client->createProject($project, $userId);
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
        return $response;
    }

    public function createComplexGuideline($brief_note, $name, $cat, $json_data, $user_id)
    {
        $context = Context::getContext();
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $category=new stdClass();
        $category->id=$cat;
        $response=$this->client->createComplexGuideline($brief_note, $name, $category, $json_data, $user_id);
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
        return $response;
    }

    public function estimateOrder($products, $project_info, $userId)
    {
        $context = Context::getContext();
        $orders=array();
        foreach ($products as $o) {
            $order=new stdClass();
            $order->userId=$userId;
            $order->description=html_entity_decode(strip_tags($o['description']));
            $order->project->id=$project_info[0]['api_project_id'];
            $order->qualityId='0';
            $order->title=$o['name'];
            if ($project_info[0]['project_type']=='Copy') {
                $order->guideline->id='p'.$project_info[0]['api_guideline_id'];
            } else {
                $words=str_word_count($o['name'])+str_word_count(strip_tags($o['description']));
                $order->guideline->maxWords=$words;
                $order->language=$project_info[0]['t_language_from'].','.$project_info[0]['t_language_to'];
                $order->toTranslate=$o['name'].' '.html_entity_decode(strip_tags($o['description']));
                $order->name='Translate';
            }
            $order->qualityId='0';
            $order->deadline=$project_info[0]['t_delivery_date'].' 00:00:00';
            $order->circle='1';
            $orders[]=$order;
        }
        $articles=new stdClass();
        $articles->order=$orders;
        $articles->totals=count($products);
        @$this->client->__setCookie("credential", $context->cookie->credential);
        if ($project_info[0]['project_type']=='Copy') {
            $response=$this->client->estimateOrder($articles, $userId);
            @$this->client->__setCookie("credential", $context->cookie->credential);
            $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
            return $response;
        } else {
            $response=$this->client->estimateTranslationOrder($articles, $userId);
            @$this->client->__setCookie("credential", $context->cookie->credential);
            $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
            return $response;
        }
    }

    public function acceptOrder($api_order_id)
    {
        $context = Context::getContext();
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $rating=new stdClass();
        $rating->general='0.84';
        $rating->guideline='0.84';
        $rating->grammar='0.84';
        $response=$this->client->acceptOrder($api_order_id, $rating, 0, time());
        return $response;
    }

    public function correctOrder($orderId, $note)
    {
        $context = Context::getContext();
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $response=$this->client->correctOrder($orderId, $note, time());
        return $response;
    }

    public function getBalance($userId)
    {
        $context = Context::getContext();
        @$this->client->__setCookie("credential", $context->cookie->credential);
        $response=$this->client->getBalance($userId);
        $context->cookie->__set('credential', $this->client->_cookies['credential'][0]);
        return $response;
    }

    public function createNewUser($email, $psw, $repsw, $returnAddress, $vertical)
    {
        $response=$this->client->createUser($email, $psw, $repsw, $returnAddress, $vertical);
        return $response;
    }

    public function activateUSer($actKey)
    {
        $response=$this->client->activateUser($actKey);
        return $response;
    }
}
