<?php
/**
 * Melscrivi Module
 *
 *  @author    Webgarh <sudhir@cwebconsultants.com>
 *  @copyright Webgarh
 *  @license   http://cwebconsultants.com
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

require_once('MelascriviPlugin.php');
//require_once(_PS_BASE_URL_.__PS_BASE_URI__.'classes/Product.php');
class MelscriviModule extends Module
{
    
    /** @var array Use to store the configuration from database */
    public $config_values;
    
    /** @var array submit values of the configuration page */
    protected static $config_post_submit_values = array("saveConfig");
    protected static $signup_post_submit_values = array("signup");
    protected static $login_post_submit_values = array("login");
    protected static $logout_post_submit_values = array("logout");
    protected static $activation_post_submit_values = array("activation");
    protected static $createproject_post_submit_values = array("createproject");
    protected static $editproject_post_submit_values = array("editproject");
    protected static $getquote_post_submit_values = array("get_quote");
    protected static $createorder_post_submit_values = array("direct_create_order");
    protected static $importxml_post_submit_values = array("import_xml");
    protected static $completexmlproducts_post_submit_values = array("xml_products");
    protected static $reviewxmlproducts_post_submit_values = array("xml_products");
    
    public function __construct()
    {
        $this->name          = 'melscrivimodule'; // internal identifier, unique and lowercase
        $this->tab           = 'front_office_features'; // backend module coresponding category
        $this->version       = '0.0.1'; // version number for the module
        $this->author        = 'Webgarh'; // module author
        $this->need_instance = 0; // load the module when displaying the "Modules" page in backend
        $this->bootstrap     = true;
        
        parent::__construct();
        
        $this->displayName = $this->l('Melascrivi: Traduzione e riscrittura Descrizioni prodotto.'); // public name
        $this->description = $this->l('Melascrivi: Traduzione e riscrittura Descrizioni prodotto for PrestaShop 1.7.x'); // public description
        
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?'); // confirmation message at uninstall
        
        $this->ps_versions_compliancy = array(
            'min' => '1.6',
            'max' => _PS_VERSION_
        );
    }
    
    /**
     * Install this module
     * @return boolean
     */
    public function install()
    {
        include dirname(__FILE__) . '/sql/install.php';
        
        return parent::install() && $this->initConfig() && $this->registerHook('actionAdminControllerSetMedia');
    }
    
    /**
     * Uninstall this module
     * @return boolean
     */
    public function uninstall()
    {
        include dirname(__FILE__) . '/sql/uninstall.php';
        
        return Configuration::deleteByName($this->name) && parent::uninstall();
    }
    
    /**
     * Add the CSS & JavaScript files you want to be loaded in BO.
     */
    public function hookActionAdminControllerSetMedia()
    {
        if ($this->isConfigPage()) {
            $this->context->controller->addJS($this->_path . 'views/js/jquery.dataTables.min.js');
            $this->context->controller->addJS($this->_path . 'views/js/common.js');
            $this->context->controller->addJS($this->_path . 'views/js/jquery.validate.min.js');
            $this->context->controller->addJS($this->_path . 'views/js/select2.min.js');
            $this->context->controller->addCSS($this->_path . 'views/css/dataTables.bootstrap.min.css');
            $this->context->controller->addCSS($this->_path . 'views/css/select2.css');
            $this->context->controller->addCSS($this->_path . 'views/css/style.css');
            $this->context->controller->addCSS('https://cdn.datatables.net/1.10.7/css/jquery.dataTables.min.css');
        }
    }
    
    /**
     * Configuration page
     */
    
    protected function initConfig()
    {
        return $this->getContent();
    }
    
    public function getContent()
    {
        return $this->postProcess();
    }
    
    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $output = '';
        
        switch ($this->getPostSubmitValue()) {
            // SignUp In Module
            case 'signup':
                try {
                    $confirmAddress = $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF'];
                    $email          = Tools::getValue('email');
                    $pass           = Tools::getValue('password');
                    $cpass          = Tools::getValue('confirm_password');
                    $vertical       = Tools::getValue('vertical');
                    $melascrivi     = new MelascriviPlugin();
                    $response       = $melascrivi->createNewUser($email, $pass, $cpass, $confirmAddress, $vertical);
                    if ($response == 'registrationOk') {
                        // Insert User Information When Sign Up
                        $res = Db::getInstance()->insert('account_info', array(
                            'email_address' => Tools::getValue('email'),
                            'password' => Tools::getValue('password'),
                            'vertical' => Tools::getValue('vertical'),
                            'is_logged_in' => 0,
                            'date_add' => date('Y-m-d H:m:s'),
                            'ip_address' => $_SERVER['REMOTE_ADDR']
                        ));
                    }
                    $last_insert_id = Db::getInstance()->Insert_ID();
                    $aCre           = 'Account creato con successo. Per favore attiva il tuo account';
                    $this->context->cookie->__set('custom_msg', $aCre);
                    return $this->redirectPage($aCre, 'SUCCESS', 'account');
                } catch (Exception $e) {
                    $e     = (array) $e;
                    $erMsg = $e['faultstring'];
                    switch ($erMsg) {
                        case 'isRegistered':
                            $a_reg = 'Sei già registrato con noi. Effettua il login ora';
                            $this->context->cookie->__set('already_registered', $a_reg);
                            return $this->redirectPage($a_reg, 'SUCCESS', 'account');
                    }
                }
                break;
            
            case 'activation':
                try {
                    $melascrivi = new MelascriviPlugin();
                    $response   = $melascrivi->activateUSer(Tools::getValue('activation_key'));
                    if ($response == 'userActivated') {
                        $act = 'Sei stato attivato con successo. Effettua il login ora';
                        $this->context->cookie->__set('user_activated', $act);
                        return $this->redirectPage($act, 'SUCCESS', 'account');
                    }
                } catch (Exception $e) {
                    $e     = (array) $e;
                    $erMsg = $e['faultstring'];
                    switch ($erMsg) {
                        case 'badUser':
                            $w_act = 'Chiave di attivazione non corretta. 
                            Inserisci la chiave di attivazione corretta per attivare il tuo account.';
                            $this->context->cookie->__set('wrong_activation_key', $w_act);
                            return $this->redirectPage($w_act, 'ERROR', 'account');
                        case 'alreadyActivatedUser':
                            $a_act = "L'utente è già stato attivato. Effettua il login ora";
                            $this->context->cookie->__set('user_already_activated', $a_act);
                            return $this->redirectPage($a_act, 'WARNING', 'account');
                    }
                }
                break;
            
            case 'login':
                //Check User Exist in database Or Not
                try {
                    $melascrivi = new MelascriviPlugin();
                    $response   = $melascrivi->login(Tools::getValue('email'), Tools::getValue('password'));
                    $ok_editor  = explode("|", $response);
                    if ($ok_editor[0] == 'okEditor') {
                        $check_login_detail = Db::getInstance()->getRow('SELECT * FROM 
                        `' . _DB_PREFIX_ . 'account_info`
        WHERE email_address = "' . Tools::getValue('email') . '" AND password="' . Tools::getValue('password') . '"');
                        if (!empty($check_login_detail)) {
                            $res = Db::getInstance()->update('account_info', array(
                                'api_key' => 'ok',
                                'api_user_id' => $ok_editor[2]
                            ), 'id= ' . $check_login_detail['id']);
                            $this->context->cookie->__set('user_id', $check_login_detail['id']);
                            $this->context->cookie->__set('api_user_id', $ok_editor[2]);
                            return $this->redirectPage('Login Successfully.', 'SUCCESS', 'account');
                        } else {
                            $res            = Db::getInstance()->insert('account_info', array(
                                'email_address' => Tools::getValue('email'),
                                'password' => Tools::getValue('password'),
                                'is_logged_in' => 0,
                                'api_key' => 'ok',
                                'api_user_id' => $ok_editor[2],
                                'date_add' => date('Y-m-d H:m:s'),
                                'ip_address' => $_SERVER['REMOTE_ADDR']
                            ));
                            $last_insert_id = Db::getInstance()->Insert_ID();
                            $this->context->cookie->__set('user_id', $last_insert_id); // Set User Id in Cookie
                            $this->context->cookie->__set('api_user_id', $ok_editor[2]); // Set User Id in Cookie
                            return $this->redirectPage('Login Successfully.', 'SUCCESS', 'account');
                        }
                    }
                } catch (Exception $e) {
                    $e     = (array) $e;
                    $erMsg = $e['faultstring'];
                    switch ($erMsg) {
                        case 'confirmRegistration':
                            $n_act = 'Il tuo account non è ancora attivato. Si prega di attivare il tuo account';
                            $this->context->cookie->__set('confirm_registration', $n_act);
                            return $this->redirectPage('Project detail successfully updated.', 'SUCCESS', 'account');
                        case 'userNotFound':
                            $w_user = "Il dettaglio dell'accesso non è corretto.
                            Si prega di inserire i dati di accesso corretti";
                            $this->context->cookie->__set('usernotfound', $w_user);
                            return $this->redirectPage($w_user, 'SUCCESS', 'account');
                    }
                }
                break;
            
            case 'logout':
                unset($this->context->cookie->api_user_id);
                unset($this->context->cookie->user_id);
                unset($this->context->cookie->credential);
                $logout = 'Disconnettersi con successo.';
                $this->context->cookie->__set('logout_success', $logout);
                return $this->redirectPage($logout, 'SUCCESS', 'account');
            // no break
            
            case 'createproject':
                try {
                    $language   = new Language($this->context->cookie->id_lang);
                    $iso_code   = $language->iso_code;
                    $pName      = Tools::getValue('project_name');
                    $melascrivi = new MelascriviPlugin();
                    $response   = $melascrivi->createProject($this->context->cookie->api_user_id, $pName, $iso_code);
                    $res        = explode(';', $response);
                    if ($res[0] == 'projectCreated') {
                        if (Tools::getValue('c_guideline') == 'block1') {
                            $description = "Description goes here for block 1";
                        } else {
                            $description = "Description goes here for block 2";
                        }
                        if (Tools::getValue('project_type') == 'Copy') {
                            if (Tools::getValue('c_guideline') == 'block1') {
                                $array_json = array(
                                    array(
                                        'type' => '4',
                                        'label' => Tools::getValue('c_guideline'),
                                        'style' => Tools::getValue('c_style'),
                                        'description' => $description,
                                        'minWords' => '70',
                                        'maxWords' => '80'
                                    ),
                                    array(
                                        'type' => '4',
                                        'label' => Tools::getValue('c_guideline'),
                                        'style' => Tools::getValue('c_style'),
                                        'description' => $description,
                                        'minWords' => '80',
                                        'maxWords' => '120'
                                    )
                                );
                            } else {
                                $array_json = array(
                                    array(
                                        'type' => '4',
                                        'label' => Tools::getValue('c_guideline'),
                                        'style' => Tools::getValue('c_style'),
                                        'description' => $description,
                                        'minWords' => '70',
                                        'maxWords' => '80'
                                    )
                                );
                            }
                            $json_data  = json_encode($array_json);
                            $melascrivi = new MelascriviPlugin();
                            $bNot       = Tools::getValue('c_brief_note');
                            $Guid      = Tools::getValue('c_guideline');
                            $Cat        = Tools::getValue('c_category');
                            $apiUser    = $this->context->cookie->api_user_id;
                            $response   = $melascrivi->createComplexGuideline($bNot, $Guid, $Cat, $json_data, $apiUser);
                            $guideline  = explode(";", $response);
                            if ($guideline[0] == 'guidelineCreated') {
                                $res            = Db::getInstance()->insert('project', array(
                                    'project_user_id' => $this->context->cookie->user_id,
                                    'project_name' => Tools::getValue('project_name'),
                                    'project_type' => Tools::getValue('project_type'),
                                    'c_guideline' => Tools::getValue('c_guideline'),
                                    'c_style' => Tools::getValue('c_style'),
                                    'c_category' => Tools::getValue('c_category'),
                                    'c_brief_note' => Tools::getValue('c_brief_note'),
                                    'c_link' => '',
                                    'c_short_description' => '',
                                    'c_long_description' => '',
                                    't_language_from' => '',
                                    't_language_to' => '',
                                    't_delivery_date' => '',
                                    't_brief_note' => '',
                                    'api_project_id' => $res[1],
                                    'api_guideline_id' => $guideline[1],
                                    'date_add' => date('Y-m-d H:m:s')
                                ));
                                $last_insert_id = Db::getInstance()->Insert_ID();
                                $pCre           = 'Progetto creato correttamente.';
                                $this->context->cookie->__set('project_created', $pCre);
                                return $this->redirectPage($pCre, 'SUCCESS', 'listproducts', $last_insert_id);
                            }
                        }
                        if (Tools::getValue('project_type') == 'Translation') {
                            $res            = Db::getInstance()->insert('project', array(
                                'project_user_id' => $this->context->cookie->user_id,
                                'project_name' => Tools::getValue('project_name'),
                                'project_type' => Tools::getValue('project_type'),
                                'c_guideline' => '',
                                'c_style' => '',
                                'c_category' => '',
                                'c_brief_note' => '',
                                'c_link' => '',
                                'c_short_description' => '',
                                'c_long_description' => '',
                                't_language_from' => Tools::getValue('t_language_from'),
                                't_language_to' => Tools::getValue('t_language_to'),
                                't_delivery_date' => Tools::getValue('t_delivery_date'),
                                't_brief_note' => Tools::getValue('t_brief_note'),
                                'api_project_id' => $res[1],
                                'api_guideline_id' => '',
                                'date_add' => date('Y-m-d H:m:s')
                            ));
                            $last_insert_id = Db::getInstance()->Insert_ID();
                            $pCre           = 'Progetto creato correttamente.';
                            $this->context->cookie->__set('project_created', $pCre);
                            return $this->redirectPage($pCre, 'SUCCESS', 'listproducts', $last_insert_id);
                        }
                    }
                } catch (Exception $e) {
                    $e     = (array) $e;
                    $erMsg = $e['faultstring'];
                    switch ($erMsg) {
                        case 'notAllowed':
                            unset($this->context->cookie->api_user_id);
                            unset($this->context->cookie->user_id);
                            unset($this->context->cookie->credential);
                            $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                            $this->context->cookie->__set('project_error', $cookieError);
                            return $this->redirectPage($cookieError, 'ERROR', 'account');
                        case 'errorEmptyValues':
                            $empVal = 'Inserite una linea guida per il progetto.';
                            $this->context->cookie->__set('project_creating_empty_values', $empVal);
                            return $this->redirectPage($empVal, 'ERROR', 'createproject');
                    }
                }
                break;
            
            case 'get_quote':
                $proId          = Tools::getValue('project_list');
                $get_user_email = Db::getInstance()->getRow('SELECT email_address FROM `' . _DB_PREFIX_ . 'account_info`
                       WHERE id = "' . $this->context->cookie->user_id . '"');
                $project_info   = Db::getInstance()->ExecuteS('SELECT * FROM `' . _DB_PREFIX_ . 'project`
                     WHERE project_user_id = "' . $this->context->cookie->user_id . '"
                     AND project_id="' . Tools::getValue('project_list') . '"');
                if (!empty(Tools::getValue('id'))) {
                    $query    = 'SELECT p.id_product, p.active, pl.name,
                         GROUP_CONCAT(DISTINCT(cl.name) SEPARATOR ",") as categories, p.price,
                         p.id_tax_rules_group, p.wholesale_price, pl.description,
                         pl.description_short, pl.link_rewrite, p.condition,
      @id_image := ifnull(pai.id_image, pi.id_image) as id_image,
        concat("http://",
                ifnull(shop_domain.value, "domain"),
                "/img/p/",
                if(CHAR_LENGTH(@id_image) >= 5,
                    concat(SUBSTRING(@id_image from - 5 FOR 1), "/"),
                    ""),
                if(CHAR_LENGTH(@id_image) >= 4,
                    concat(SUBSTRING(@id_image from - 4 FOR 1), "/"),
                    ""),
                if(CHAR_LENGTH(@id_image) >= 3,
                    concat(SUBSTRING(@id_image from - 3 FOR 1), "/"),
                    ""),
                if(CHAR_LENGTH(@id_image) >= 2,
                    concat(SUBSTRING(@id_image from - 2 FOR 1), "/"),
                    ""),
                if(CHAR_LENGTH(@id_image) >= 1,
                    concat(SUBSTRING(@id_image from - 1 FOR 1), "/"),
                    ""),
                @id_image,
                ".jpg") as image_url

                FROM ' . _DB_PREFIX_ . 'product p
    LEFT JOIN ' . _DB_PREFIX_ . 'product_lang pl ON (p.id_product = pl.id_product)
    LEFT JOIN ' . _DB_PREFIX_ . 'category_product cp ON (p.id_product = cp.id_product)
    LEFT JOIN ' . _DB_PREFIX_ . 'category_lang cl ON (cp.id_category = cl.id_category)
    LEFT JOIN ' . _DB_PREFIX_ . 'category c ON (cp.id_category = c.id_category)
    LEFT JOIN ' . _DB_PREFIX_ . 'product_tag pt ON (p.id_product = pt.id_product)
                LEFT JOIN
        ' . _DB_PREFIX_ . 'product_attribute pa ON (p.id_product = pa.id_product)
                    LEFT JOIN
        ' . _DB_PREFIX_ . 'product_attribute_image pai ON (pa.id_product_attribute = pai.id_product_attribute)
            LEFT JOIN
        ' . _DB_PREFIX_ . 'image pi ON p.id_product = pi.id_product
            LEFT JOIN
        ' . _DB_PREFIX_ . 'configuration shop_domain ON shop_domain.name = "PS_SHOP_DOMAIN"
        WHERE p.id_product IN (' . implode(",", Tools::getValue('id')) . ')
        GROUP BY p.id_product';
                    $products = Db::getInstance()->ExecuteS($query);
                    try {
                        $apiUser    = $this->context->cookie->api_user_id;
                        $melascrivi = new MelascriviPlugin();
                        $response   = $melascrivi->estimateOrder($products, $project_info, $apiUser);
                        $cost       = json_decode($response);
                        
                        $check_existing_project_order = Db::getInstance()->getRow('SELECT * 
                            FROM `' . _DB_PREFIX_ . 'project_order`
                            WHERE project_id = "' . Tools::getValue('project_list') . '"
                            AND date_add="' . date('Y-m-d 00:00:00') . '" order by project_order_id desc');
                        if (empty($check_existing_project_order)) {
                            $res = Db::getInstance()->insert('project_order', array(
                                'project_id' => Tools::getValue('project_list'),
                                'quote_price' => $cost->cost,
                                'quote_date_time' => date('Y-m-d H:i:s'),
                                'quote_details' => $cost->estimateTime,
                                'total_products' => count($products),
                                'date_add' => date('Y-m-d'),
                                'user_api_id' => $this->context->cookie->api_user_id,
                                'ip_address' => $_SERVER['REMOTE_ADDR'],
                                'user_email_address' => $get_user_email['email_address']
                            ));
                        } else {
                            $res = Db::getInstance()->update('project_order', array(
                                'quote_price' => $cost->cost,
                                'quote_date_time' => date('Y-m-d H:i:s'),
                                'quote_details' => $cost->estimateTime,
                                'total_products' => count($products),
                                'user_api_id' => $this->context->cookie->api_user_id
                            ), 'project_order_id= ' . $check_existing_project_order['project_order_id'] . '
                               AND user_api_id=' . $this->context->cookie->api_user_id);
                        }
                        Db::getInstance()->execute('DELETE FROM ' . _DB_PREFIX_ . 'project_products
                             WHERE `project_id` = "' . Tools::getValue('project_list') . '"');
                        $path = dirname(dirname(dirname(__FILE__))) . '/classes/Product.php';
                        include($path);
                        $words_count = 0;
                        foreach ($products as $list) {
                            $desc        = $list['description'];
                            $words       = str_word_count($list['name']) + str_word_count(strip_tags($desc));
                            $words_count = $words_count + $words;
                            $product     = new Product((int) $list['id_product']);
                            $link        = new Link();
                            $product_url = $link->getProductLink($product);
                            $res         = Db::getInstance()->insert('project_products', array(
                                'project_id' => Tools::getValue('project_list'),
                                'product_id' => $list['id_product'],
                                'product_url' => $product_url,
                                'date_add' => date('Y-m-d')
                            ));
                        }
                        if (!empty($res)) {
                            $pList = Tools::getValue('project_list');
                            return $this->redirectPage('Success', 'SUCCESS', 'reviewquote', $pList, $words_count);
                        }
                    } catch (Exception $e) {
                        $e     = (array) $e;
                        $erMsg = $e['faultstring'];
                        switch ($erMsg) {
                            case 'notAllowed':
                                unset($this->context->cookie->api_user_id);
                                unset($this->context->cookie->user_id);
                                unset($this->context->cookie->credential);
                                $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                                $this->context->cookie->__set('project_error', $cookieError);
                                return $this->redirectPage($cookieError, 'ERROR', 'account');
                            case 'errorEmptyValues':
                                $empVal = 'Inserite una linea guida per il progetto.';
                                $this->context->cookie->__set('empty_error', $empVal);
                                return $this->redirectPage($empVal, 'ERROR', 'listproducts', $proId);
                        }
                    }
                } else {
                    $pList = Tools::getValue('project_list');
                    $eep   = 'Attenzione selezionate almeno 1 prodotto.';
                    $this->context->cookie->__set('empty_error_products', $eep);
                    return $this->redirectPage($eep, 'ERROR', 'listproducts', $pList);
                }
                break;
            
            case 'direct_create_order':
                $order_info = Db::getInstance()->getRow('SELECT order_sent_to_api,project_id
                  FROM `' . _DB_PREFIX_ . 'project_order`
                  WHERE project_order_id = "' . Tools::getValue('order_id') . '"');
                if (empty($order_info['order_sent_to_api'])) {
                    $products_list = Db::getInstance()->ExecuteS('select pp.*, pl.name,pr.project_name,
                      pr.project_type,pr.api_project_id,
                      pr.api_guideline_id,pr.c_style,pr.c_category, pl.description,
                      pl.description_short,pr.t_language_from,pr.t_language_to,
                      pr.t_delivery_date from `' . _DB_PREFIX_ . 'project_products` as pp
                      LEFT JOIN `' . _DB_PREFIX_ . 'product` as p on (p.id_product=pp.product_id)
                      LEFT JOIN `' . _DB_PREFIX_ . 'product_lang` pl ON (pp.product_id = pl.id_product)
                      LEFT JOIN `' . _DB_PREFIX_ . 'project` as pr on (pr.project_id=pp.project_id)
                      where pp.project_id="' . $order_info['project_id'] . '" group by p.id_product');
                    try {
                        $language    = new Language($this->context->cookie->id_lang);
                        $iso_code    = $language->iso_code;
                        $apiUser     = $this->context->cookie->api_user_id;
                        $melascrivi  = new MelascriviPlugin();
                        $response    = $melascrivi->requestOrder($apiUser, $products_list, $iso_code);
                        $res         = explode(";", $response);
                        $array_order = array_chunk($res, "2");
                        foreach ($array_order as $api_order_id) {
                            if ($api_order_id[1] != '') {
                                $res = Db::getInstance()->insert('api_orders', array(
                                    'api_user_id' => $this->context->cookie->api_user_id,
                                    'order_id' => Tools::getValue('order_id'),
                                    'api_order_id' => $api_order_id[1]
                                ));
                            }
                        }
                        $res_update = Db::getInstance()->update('project_order', array(
                            'order_sent_to_api' => '1',
                            'payment_status' => '1'
                        ), 'project_order_id= ' . Tools::getValue('order_id'));
                        if (!empty($res_update)) {
                            return $this->redirectPage('Success', 'SUCCESS', 'payment_success');
                        }
                    } catch (Exception $e) {
                        $e     = (array) $e;
                        $erMsg = $e['faultstring'];
                        switch ($erMsg) {
                            case 'notAllowed':
                                unset($this->context->cookie->api_user_id);
                                unset($this->context->cookie->user_id);
                                unset($this->context->cookie->credential);
                                $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                                $this->context->cookie->__set('project_error', $cookieError);
                                return $this->redirectPage($cookieError, 'ERROR', 'account');
                            case 'errorEmptyValues':
                                $empVal = 'Inserite una linea guida per il progetto.';
                                $this->context->cookie->__set('empty_error', $empVal);
                                return $this->redirectPage($pCre, 'SUCCESS', 'listproducts', $order_info['project_id']);
                            case 'errorNotEnoughMoney':
                                $insufbal = 'Equilibrio insufficiente nel tuo portafoglio.';
                                $this->context->cookie->__set('balance_error', $insufbal);
                                return $this->redirectPage($insufbal, 'ERROR', 'createproject');
                        }
                    }
                }
                break;
            
            case 'import_xml':
                $xml_dir_path = $_SERVER['DOCUMENT_ROOT'] . __PS_BASE_URI__ . 'upload/';
                $tmp_name     = $_FILES["xml_file"]["tmp_name"];
                $name         = rand() . basename($_FILES["xml_file"]["name"]);
                $full_path    = $xml_dir_path . $name;
                $xml          = (array) simplexml_load_file($tmp_name);
                $products     = (array) $xml['product'][0];
                $mela_id      = $products['mela-id'];
                $order_id     = Db::getInstance()->getRow('SELECT * FROM `' . _DB_PREFIX_ . 'api_orders`
                  WHERE api_order_id = "' . $mela_id . '"');
                if (move_uploaded_file($tmp_name, $full_path)) {
                    $xml_review_info = Db::getInstance()->getRow('SELECT id,xml_file_path
                        FROM `' . _DB_PREFIX_ . 'order_review`
                        WHERE order_id = "' . $order_id['order_id'] . '"');
                    if (empty($xml_review_info)) {
                        $res            = Db::getInstance()->insert('order_review', array(
                            'order_id' => $order_id['order_id'],
                            'xml_file_path' => $full_path,
                            'status' => 'review',
                            'accepted_product_ids' => '',
                            'review_product_ids' => '',
                            'review_date' => date('Y-m-d'),
                            'review_api_id' => '',
                            'review_status' => 'pending'
                        ));
                        $last_insert_id = Db::getInstance()->Insert_ID();
                        return $this->redirectPage('Import successfully', 'ERROR', 'importxmlfile', $last_insert_id);
                    } else {
                        unlink($xml_review_info['xml_file_path']);
                        $res = Db::getInstance()->update('order_review', array(
                            'xml_file_path' => $full_path,
                            'status' => 'review',
                            'review_date' => date('Y-m-d'),
                            'review_status' => 'pending'
                        ), 'id= ' . $xml_review_info['id']);
                        return $this->redirectPage('Import success', 'ERROR', 'importxmlfile', $xml_review_info['id']);
                    }
                }
                break;
            
            case 'accept':
                $revId = Tools::getValue('xml_review_id');
                if (!empty(Tools::getValue('product_id'))) {
                    $review_info           = Db::getInstance()->getRow('SELECT order_id FROM 
                    `' . _DB_PREFIX_ . 'order_review`
                    WHERE id = "' . Tools::getValue('xml_review_id') . '"');
                    $order_id              = $review_info['order_id'];
                    $order_info            = Db::getInstance()->getRow('SELECT project_id FROM 
                    `' . _DB_PREFIX_ . 'project_order` WHERE project_order_id = "' . $order_id . '"');
                    $project_id            = $order_info['project_id'];
                    $project_products_info = Db::getInstance()->getRow('SELECT count(product_id) as total 
                    FROM `' . _DB_PREFIX_ . 'project_products`
                    WHERE project_id = "' . $project_id . '"');
                    $count                 = count(Tools::getValue('product_id'));
                    $xml_lang              = Tools::getValue('dest_lang_' . Tools::getValue('product_id')[0]);
                    $lang                  = Db::getInstance()->getRow('SELECT id_lang FROM `' . _DB_PREFIX_ . 'lang`
                        WHERE iso_code = "' . $xml_lang . '"');
                    if (!empty($lang)) {
                        $acc_ids = array();
                        foreach (Tools::getValue('product_id') as $ids) {
                            $lang_id  = Db::getInstance()->getRow('SELECT id_lang FROM `' . _DB_PREFIX_ . 'lang`
                        WHERE iso_code = "' . Tools::getValue('dest_lang_' . $ids) . '"');
                            $get_id_shop = Db::getInstance()->getRow('SELECT id_shop FROM
                            `' . _DB_PREFIX_ . 'product_lang`
                        WHERE id_product = "' . $ids . '"');
                            $check_product_for_lang = Db::getInstance()->getRow('SELECT * FROM
                        `' . _DB_PREFIX_ . 'product_lang`
                        WHERE id_product = "' . $ids . '" AND id_lang = "' . $lang_id['id_lang'] . '"');
                            $shopId                 = $get_id_shop['id_shop'];
                            if (!empty($check_product_for_lang)) {
                                $res = Db::getInstance()->update('product_lang', array(
                                    'name' => Tools::getValue('product_title_' . $ids),
                                    'description' => Tools::getValue('product_desc_' . $ids)
                                ), 'id_product= ' . $ids . ' AND id_lang=' . $lang_id['id_lang']);
                            } else {
                                $res = Db::getInstance()->insert('product_lang', array(
                                    'id_product' => $ids,
                                    'description' => Tools::getValue('product_desc_' . $ids),
                                    'name' => Tools::getValue('product_title_' . $ids),
                                    'id_lang' => $lang_id['id_lang'],
                                    'id_shop' => $shopId,
                                    'link_rewrite' => str_replace(" ", "-", Tools::getValue('product_title_' . $ids))
                                ));
                            }
                            try {
                                $melascrivi = new MelascriviPlugin();
                                $response   = $melascrivi->acceptOrder(Tools::getValue('mela_id_' . $ids));
                                if ($response == 'ArticleAccepted') {
                                    $acc_ids[]    = Tools::getValue('mela_id_' . $ids);
                                    $accepted_ids = Db::getInstance()->getRow('SELECT accepted_product_ids,
                              review_product_ids
                              FROM `' . _DB_PREFIX_ . 'order_review`
                              WHERE id = "' . Tools::getValue('xml_review_id') . '"');
                                    $review_ids   = $accepted_ids['accepted_product_ids'];
                                    if (!empty($review_ids)) {
                                        $exp_ids        = explode(",", $review_ids);
                                        $remove_ids     = array_diff($exp_ids, array(
                                            Tools::getValue('mela_id_' . $ids)
                                        ));
                                        $new_review_ids = implode(",", $remove_ids);
                                        $res            = Db::getInstance()->update('order_review', array(
                                            'review_product_ids' => $new_review_ids
                                        ), 'id= ' . Tools::getValue('xml_review_id'));
                                    }
                                    if (empty($accepted_ids['accepted_product_ids'])) {
                                        $accepted_ids = $ids;
                                    } else {
                                        $accepted_ids = $accepted_ids['accepted_product_ids'] . ',' . $ids;
                                    }
                                    $res = Db::getInstance()->update('order_review', array(
                                        'accepted_product_ids' => $accepted_ids
                                    ), 'id= ' . Tools::getValue('xml_review_id'));
                                }
                            } catch (Exception $e) {
                                $e     = (array) $e;
                                $erMsg = $e['faultstring'];
                                switch ($erMsg) {
                                    case 'errorNoOwner':
                                        unset($this->context->cookie->api_user_id);
                                        unset($this->context->cookie->user_id);
                                        unset($this->context->cookie->credential);
                                        $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                                        $this->context->cookie->__set('project_error', $cookieError);
                                        return $this->redirectPage($cookieError, 'ERROR', 'account');
                                    case 'wrongStatusError':
                                        $this->context->cookie->__set('project_error_xml', $erMsg . '.');
                                        return $this->redirectPage($erMsg, 'ERROR', 'importxmlfile', $revId);
                                }
                            }
                        }
                    } else {
                        $langEr = 'Attenzione: la lingua scelta non è stata resa attiva in Prestashop.';
                        $this->context->cookie->__set('lang_error_xml', $langEr . '.');
                        return $this->redirectPage($erMsg, 'ERROR', 'importxmlfile', $revId);
                    }
                    if ($count == count($acc_ids)) {
                        $accepted_ids_all = Db::getInstance()->getRow('SELECT accepted_product_ids
                    FROM `' . _DB_PREFIX_ . 'order_review`
                    WHERE id = "' . Tools::getValue('xml_review_id') . '"');
                        $exp_acc_all      = explode(",", $accepted_ids_all['accepted_product_ids']);
                        if (count($exp_acc_all) == $project_products_info['total']) {
                            $res = Db::getInstance()->update('project_order', array(
                                'order_delivered' => '1'
                            ), 'project_order_id= ' . $order_id);
                        }
                        $accept_msg = 'Prodotti accettati con successo.';
                        $this->context->cookie->__set('accept_products_success', $accept_msg);
                        return $this->redirectPage('Im', 'SUCCESS', 'importxmlfile', Tools::getValue('xml_review_id'));
                    }
                } else {
                    $sPro = 'Attenzione selezionate almeno 1 prodotto.';
                    $this->context->cookie->__set('accept_select_products', $sPro);
                    return $this->redirectPage($sPro, 'ERROR', 'importxmlfile', Tools::getValue('xml_review_id'));
                }
                break;
            
            case 'review':
                $revId = Tools::getValue('xml_review_id');
                if (!empty(Tools::getValue('product_id'))) {
                    $count_rev = count(Tools::getValue('product_id'));
                    $rev_ids   = array();
                    foreach (Tools::getValue('product_id') as $ids) {
                        try {
                            $comment    = Tools::getValue('review_note_' . $ids);
                            $note       = $comment;
                            $melascrivi = new MelascriviPlugin();
                            $response   = $melascrivi->correctOrder(Tools::getValue('mela_id_' . $ids), $note);
                            if ($response == 'ArticleCorrection') {
                                $rev_ids[]  = Tools::getValue('mela_id_' . $ids);
                                $review_ids = Db::getInstance()->getRow('SELECT review_product_ids 
                               FROM `' . _DB_PREFIX_ . 'order_review`
                               WHERE id = "' . Tools::getValue('xml_review_id') . '"');
                                if (empty($review_ids['review_product_ids'])) {
                                    $review_ids = $ids;
                                } else {
                                    $review_ids = $review_ids['review_product_ids'] . ',' . $ids;
                                }
                                $res = Db::getInstance()->update('order_review', array(
                                    'review_product_ids' => $review_ids
                                ), 'id= ' . Tools::getValue('xml_review_id'));
                            }
                        } catch (Exception $e) {
                            $e     = (array) $e;
                            $erMsg = $e['faultstring'];
                            switch ($erMsg) {
                                case 'errorNoOwner':
                                    unset($this->context->cookie->api_user_id);
                                    unset($this->context->cookie->user_id);
                                    unset($this->context->cookie->credential);
                                    $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                                    $this->context->cookie->__set('project_error', $cookieError);
                                    return $this->redirectPage($cookieError, 'ERROR', 'account');
                                case 'wrongStatusError':
                                    $this->context->cookie->__set('project_error_xml', $erMsg . '. Please try Again.');
                                    return $this->redirectPage($erMsg, 'ERROR', 'importxmlfile', $revId);
                            }
                        }
                    }
                    if ($count_rev == count($rev_ids)) {
                        $for_rev = 'I prodotti danno per la revisione con successo';
                        $this->context->cookie->__set('product_for_review', $for_rev);
                        return $this->redirectPage('Im', 'SUCCESS', 'importxmlfile', Tools::getValue('xml_review_id'));
                    }
                } else {
                    $acc_pro = 'Attenzione selezionate almeno 1 prodotto.';
                    $this->context->cookie->__set('accept_select_products', $acc_pro);
                    return $this->redirectPage($acc_pro, 'SUCCESS', 'importxmlfile', Tools::getValue('xml_review_id'));
                }
                break;
            
            default:
                $output .= $this->renderForm();
                break;
        }
        
        return $output;
    }
    
    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        if (!empty($this->context->cookie->api_user_id)) {
            try {
                $melascrivi        = new MelascriviPlugin();
                $available_balance = $melascrivi->getBalance($this->context->cookie->api_user_id);
                $this->context->smarty->assign('available_balance', $available_balance);
            } catch (Exception $e) {
                $e     = (array) $e;
                $erMsg = $e['faultstring'];
                switch ($erMsg) {
                    case 'notAllowed':
                        unset($this->context->cookie->api_user_id);
                        unset($this->context->cookie->user_id);
                        unset($this->context->cookie->credential);
                        $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                        $this->context->cookie->__set('project_error', $cookieError);
                        return $this->redirectPage($cookieError, 'ERROR', 'account');
                }
            }
        }
        $admin_dir_name = explode('/', _PS_ADMIN_DIR_);
        /* Category Array */
        $categories     = array(
            '1' => 'Altre Categorie',
            '2' => 'Animali',
            '3' => 'Arredamento',
            '4' => 'Assicurazioni',
            '5' => 'Auto e Moto',
            '6' => 'Banche',
            '7' => 'Bellezza e Benessere',
            '8' => 'Casa e Giardino',
            '9' => 'Cinema e TV',
            '10' => 'Computer e Programmi',
            '11' => 'Cronaca',
            '12' => 'Cucina e ricette',
            '13' => 'Cultura e Spettacolo',
            '14' => 'Diritto',
            '15' => 'Elettronica',
            '16' => 'Elettrodomestici',
            '17' => 'Famiglia',
            '18' => 'Fantasy',
            '19' => 'Economia e Finanza',
            '20' => 'Fotografia',
            '21' => 'Fumetti',
            '22' => 'Gossip',
            '23' => 'Hobby e Giochi',
            '24' => 'Internet',
            '25' => 'Investimenti',
            '26' => 'Lavoro',
            '27' => 'Libri',
            '28' => 'Mangiare e Bere',
            '29' => 'Moda',
            '30' => 'Musica',
            '31' => 'Narrativa',
            '32' => 'Neonati e Bimbi',
            '33' => 'Politica',
            '34' => 'Prestiti',
            '36' => 'Salute',
            '37' => 'Scienze',
            '38' => 'Shopping Online',
            '39' => 'Sport',
            '40' => 'Strumenti Musicali',
            '41' => 'Telefonia',
            '42' => 'Videogiochi',
            '43' => 'Viaggi e Turismo',
            '44' => 'Tecnologia',
            '53' => 'Adult'
        );
        
        $styles            = array(
            '1' => 'consiglio',
            '2' => 'guida',
            '3' => 'tutorial',
            '4' => 'consiglio per altri acquirenti',
            '5' => 'esperienza personale',
            '6' => 'idea',
            '7' => 'opinione',
            '8' => 'pensiero',
            '9' => 'recensione',
            '10' => 'sentito dire',
            '11' => 'soluzione',
            '12' => 'stile giornalistico',
            '13' => 'trucchi',
            '14' => 'stile libero'
        );
        $count_xml_product = '';
        $base_url          = _PS_BASE_URL_ . __PS_BASE_URI__;
        $admin_dir_path    = _PS_BASE_URL_ . __PS_BASE_URI__ . end($admin_dir_name);
        $tab               = (!empty($_REQUEST['tab'])) ? $_REQUEST['tab'] : '';
        $words             = (!empty(Tools::getValue('words'))) ? Tools::getValue('words') : '0';
        $project_selection = (!empty($_REQUEST['project'])) ? $_REQUEST['project'] : '';
        $review_id         = (!empty($_REQUEST['review_id'])) ? $_REQUEST['review_id'] : '';
        if (!empty($review_id)) {
            $xml_review_info = Db::getInstance()->getRow('SELECT * FROM `' . _DB_PREFIX_ . 'order_review`
                                                       WHERE id = "' . $review_id . '"');
            $completed_ids   = $xml_review_info['accepted_product_ids'];
            $completed_ids   = explode(",", $completed_ids);
            $rev_ids         = $xml_review_info['review_product_ids'];
            $rev_ids         = explode(",", $rev_ids);
            $xml             = (array) simplexml_load_file($xml_review_info['xml_file_path']);
            $a               = (array) $xml['product'];
            if (!empty($a[0])) {
                $count_xml_product = count($a);
            } else {
                $count_xml_product = '1';
            }
        } else {
            $xml            = array();
            $xml['product'] = '';
            $completed_ids  = array();
            $rev_ids        = array();
        }
        if ($tab == 'payment_success') {
            $transaction_id = Tools::getValue('tx');
            if (Tools::getValue('st') == 'Completed') {
                $res = Db::getInstance()->update('project_order', array(
                    'payment_status' => 1,
                    'payment_transaction_id' => $transaction_id,
                    'amount_paid' => Tools::getValue('amt'),
                    'payment_date_time' => date('Y-m-d H:i:s'),
                    'payment_method' => 'paypal'
                ), 'project_order_id= ' . Tools::getValue('order'));
            }
            $order_info = Db::getInstance()->getRow('SELECT order_sent_to_api,project_id,
                                     quote_price FROM `' . _DB_PREFIX_ . 'project_order`
                                     WHERE project_order_id = "' . Tools::getValue('order') . '"');
            if (empty($order_info['order_sent_to_api'])) {
                $melascrivi        = new MelascriviPlugin();
                $available_balance = $melascrivi->getBalance($this->context->cookie->api_user_id);
                if ($available_balance >= $order_info['quote_price']) {
                    $products_list = Db::getInstance()->ExecuteS('select pp.*, pl.name,pr.project_name,pr.project_type,
                             pr.api_project_id,pr.api_guideline_id,
                             pr.c_style,pr.c_category, pl.description, pl.description_short,pr.t_language_from,
                             pr.t_language_to,pr.t_delivery_date from `' . _DB_PREFIX_ . 'project_products` as pp
                             LEFT JOIN `' . _DB_PREFIX_ . 'product` as p on (p.id_product=pp.product_id)
                             LEFT JOIN `' . _DB_PREFIX_ . 'product_lang` pl ON (pp.product_id = pl.id_product)
                             LEFT JOIN `' . _DB_PREFIX_ . 'project` as pr on (pr.project_id=pp.project_id)
                             where pp.project_id="' . $order_info['project_id'] . '" group by p.id_product');
                    try {
                        $language    = new Language($this->context->cookie->id_lang);
                        $iso_code    = $language->iso_code;
                        $apiUser     = $this->context->cookie->api_user_id;
                        $melascrivi  = new MelascriviPlugin();
                        $response    = $melascrivi->requestOrder($apiUser, $products_list, $iso_code);
                        $res         = explode(";", $response);
                        $array_order = array_chunk($res, "2");
                        foreach ($array_order as $api_order_id) {
                            if ($api_order_id[1] != '') {
                                $res = Db::getInstance()->insert('api_orders', array(
                                    'api_user_id' => $this->context->cookie->api_user_id,
                                    'order_id' => Tools::getValue('order'),
                                    'api_order_id' => $api_order_id[1]
                                ));
                            }
                        }
                        $res_update = Db::getInstance()->update('project_order', array(
                            'order_sent_to_api' => '1'
                        ), 'project_order_id= ' . Tools::getValue('order'));
                        if (!empty($res_update)) {
                            return $this->redirectPage('Success', 'SUCCESS', 'payment_success');
                        }
                    } catch (Exception $e) {
                        $e     = (array) $e;
                        $erMsg = $e['faultstring'];
                        switch ($erMsg) {
                            case 'notAllowed':
                                unset($this->context->cookie->api_user_id);
                                unset($this->context->cookie->user_id);
                                unset($this->context->cookie->credential);
                                $cookieError = 'Qualcosa è andato storto. Per favore, prova di nuovo.';
                                $this->context->cookie->__set('project_error', $cookieError);
                                return $this->redirectPage($cookieError, 'ERROR', 'account');
                            case 'errorEmptyValues':
                                $proId  = Tools::getValue('project_list');
                                $empVal = 'Inserite una linea guida per il progetto.';
                                $this->context->cookie->__set('empty_error', $empVal);
                                return $this->redirectPage($empVal, 'ERROR', 'listproducts', $proId);
                        }
                    }
                }
            }
        }
        $project_id      = (!empty(Tools::getValue('project_id'))) ? Tools::getValue('project_id') : '';
        $user_info       = Db::getInstance()->getRow('SELECT `email_address`,
                                             `vertical` FROM `' . _DB_PREFIX_ . 'account_info`  
                                             WHERE id = "' . $this->context->cookie->user_id . '"');
        $categories_list = Db::getInstance()->ExecuteS("select distinct id_category,name 
                                                     from " . _DB_PREFIX_ . "category_lang order by name asc");
        
        $projects_list  = Db::getInstance()->ExecuteS('SELECT p.`project_id`,p.`project_name`,p.`project_type`,
        p.`c_guideline`,p.`c_style`,
        po.`payment_status`,po.`quote_details`,po.`payment_date_time`,po.`order_sent_to_api`,po.`order_delivered`,
        po.`project_order_id`,po.`date_add`,ord_r.`review_product_ids` FROM `' . _DB_PREFIX_ . 'project` as p 
        LEFT JOIN `' . _DB_PREFIX_ . 'project_order` as po on (po.project_id=p.project_id  AND DATE(po.`date_add`)= CURDATE()) 
        LEFT JOIN `' . _DB_PREFIX_ . 'order_review` as ord_r on (po.project_order_id=ord_r.order_id) 
        WHERE project_user_id = "' . $this->context->cookie->user_id . '" group by p.project_id');
        $project_detail = Db::getInstance()->getRow('SELECT * FROM 
        `' . _DB_PREFIX_ . 'project` WHERE project_id = "' . $project_id . '"');
        $query          = 'SELECT p.id_product, p.active, pl.name,
        GROUP_CONCAT(DISTINCT(cl.name) SEPARATOR ",") as categories,
                 p.price, p.id_tax_rules_group, p.wholesale_price, pl.description,
                 pl.description_short, pl.link_rewrite, p.condition,
  @id_image := ifnull(pai.id_image, pi.id_image) as id_image,
    concat("http://",
            ifnull(shop_domain.value, "domain"),
            "/img/p/",
            if(CHAR_LENGTH(@id_image) >= 5,
                concat(SUBSTRING(@id_image from - 5 FOR 1), "/"),
                ""),
            if(CHAR_LENGTH(@id_image) >= 4,
                concat(SUBSTRING(@id_image from - 4 FOR 1), "/"),
                ""),
            if(CHAR_LENGTH(@id_image) >= 3,
                concat(SUBSTRING(@id_image from - 3 FOR 1), "/"),
                ""),
            if(CHAR_LENGTH(@id_image) >= 2,
                concat(SUBSTRING(@id_image from - 2 FOR 1), "/"),
                ""),
            if(CHAR_LENGTH(@id_image) >= 1,
                concat(SUBSTRING(@id_image from - 1 FOR 1), "/"),
                ""),
            @id_image,
            ".jpg") as image_url
            
            FROM ' . _DB_PREFIX_ . 'product p
LEFT JOIN ' . _DB_PREFIX_ . 'product_lang pl ON (p.id_product = pl.id_product)
LEFT JOIN ' . _DB_PREFIX_ . 'category_product cp ON (p.id_product = cp.id_product)
LEFT JOIN ' . _DB_PREFIX_ . 'category_lang cl ON (cp.id_category = cl.id_category)
LEFT JOIN ' . _DB_PREFIX_ . 'category c ON (cp.id_category = c.id_category)
LEFT JOIN ' . _DB_PREFIX_ . 'product_tag pt ON (p.id_product = pt.id_product)
            LEFT JOIN
    ' . _DB_PREFIX_ . 'product_attribute pa ON (p.id_product = pa.id_product)
                LEFT JOIN
    ' . _DB_PREFIX_ . 'product_attribute_image pai ON (pa.id_product_attribute = pai.id_product_attribute)
        LEFT JOIN
    ' . _DB_PREFIX_ . 'image pi ON p.id_product = pi.id_product
        LEFT JOIN
    ' . _DB_PREFIX_ . 'configuration shop_domain ON shop_domain.name = "PS_SHOP_DOMAIN"
    WHERE pl.id_lang = 1
AND cl.id_lang = 1
GROUP BY p.id_product';
        $products       = Db::getInstance()->ExecuteS($query);
        $product_ids    = array();
        foreach ($products as $list) {
            $product_ids[] = $list['id_product'];
        }
        $array_lang = array(
            'en',
            'fr',
            'es',
            'pt',
            'de',
            'nl',
            'pl',
            'cs',
            'da',
            'no',
            'sv',
            'ru',
            'zh',
            'ar',
            'it'
        );
        $langs      = Db::getInstance()->executeS('SELECT `iso_code`,`name` FROM `' . _DB_PREFIX_ . 'lang`
                        WHERE active = "1" order by id_lang');
        $new_langs  = array();
        foreach ($langs as $list) {
            if (in_array($list['iso_code'], $array_lang)) {
                $new_langs[] = $list;
            }
        }
        /* Get Quote Informtaion */
        $today_date = date('Y-m-d') . ' 00:00:00';
        $quote_info = Db::getInstance()->getRow('SELECT po.*,p.* FROM `' . _DB_PREFIX_ . 'project_order` as po 
                                   LEFT JOIN `' . _DB_PREFIX_ . 'project` as p on (p.project_id=po.project_id)  
                                   WHERE po.user_api_id = "' . $this->context->cookie->api_user_id . '" 
                                   AND po.date_add="' . $today_date . '" AND po.project_id="' . $project_selection . '" 
                                   order by po.project_order_id desc');
        $this->context->smarty->assign('userID', $this->context->cookie->user_id);
        $this->context->smarty->assign('apiUserID', $this->context->cookie->api_user_id);
        $this->context->smarty->assign('user_info', $user_info);
        $this->context->smarty->assign('userprojects', $projects_list);
        $this->context->smarty->assign('project_detail', $project_detail);
        $this->context->smarty->assign('tab', $tab);
        $this->context->smarty->assign('base_url', $base_url);
        $this->context->smarty->assign('admin_url', $admin_dir_path);
        $this->context->smarty->assign('products', $products);
        $this->context->smarty->assign('categories_shop', $categories_list);
        $this->context->smarty->assign('products_id', $product_ids);
        $this->context->smarty->assign('project_for_product', $project_selection);
        $this->context->smarty->assign('categories', $categories);
        $this->context->smarty->assign('styles', $styles);
        $this->context->smarty->assign('quote_info', $quote_info);
        $this->context->smarty->assign('words', $words);
        $this->context->smarty->assign('review_xml_order_data', $xml['product']);
        $this->context->smarty->assign('review_id', $review_id);
        $this->context->smarty->assign('completed_ids', $completed_ids);
        $this->context->smarty->assign('rev_ids', $rev_ids);
        $this->context->smarty->assign('count_xml_product', $count_xml_product);
        $this->context->smarty->assign('langs_list', $new_langs);
        $exp      = explode("&tab=", $_SERVER['REQUEST_URI']);
        $form_url = $exp[0];
        $this->context->smarty->assign('form_url', $form_url);
        // Account Created Message
        if (isset($this->context->cookie->custom_msg)) :
            $this->context->smarty->assign('custom_msg', "
            <div class='msg'>" . $this->context->cookie->custom_msg . "</div>");
            unset($this->context->cookie->custom_msg);
        else :
            $this->context->smarty->assign('custom_msg', '');
        endif;
        // Account Already Register Message
        if (isset($this->context->cookie->already_registered)) :
            $this->context->smarty->assign('already_registered', "
            <div class='already_registered'>" . $this->context->cookie->already_registered . "</div>");
            unset($this->context->cookie->already_registered);
        else :
            $this->context->smarty->assign('already_registered', '');
        endif;
        // User Activated Message
        if (isset($this->context->cookie->user_activated)) :
            $this->context->smarty->assign('user_activated', "
            <div class='user_activated'>" . $this->context->cookie->user_activated . "</div>");
            unset($this->context->cookie->user_activated);
        else :
            $this->context->smarty->assign('user_activated', '');
        endif;
        // Wrong Activation Key Message
        if (isset($this->context->cookie->wrong_activation_key)) :
            $this->context->smarty->assign('wrong_activation_key', "
            <div class='wrong_activation_key'>" . $this->context->cookie->wrong_activation_key . "</div>");
            unset($this->context->cookie->wrong_activation_key);
        else :
            $this->context->smarty->assign('wrong_activation_key', '');
        endif;
        // Already Activated Message
        if (isset($this->context->cookie->user_already_activated)) :
            $this->context->smarty->assign('user_already_activated', "
            <div class='user_already_activated'>" . $this->context->cookie->user_already_activated . "</div>");
            unset($this->context->cookie->user_already_activated);
        else :
            $this->context->smarty->assign('user_already_activated', '');
        endif;
        // Not Activated yet Message
        if (isset($this->context->cookie->confirm_registration)) :
            $this->context->smarty->assign('confirm_registration_msg', "
            <div class='confirm_registration_msg'>" . $this->context->cookie->confirm_registration . "</div>");
            unset($this->context->cookie->confirm_registration);
        else :
            $this->context->smarty->assign('confirm_registration_msg', '');
        endif;
        // Incorrect Login Detail Message
        if (isset($this->context->cookie->usernotfound)) :
            $this->context->smarty->assign('usernotfound', "
            <div class='usernotfound'>" . $this->context->cookie->usernotfound . "</div>");
            unset($this->context->cookie->usernotfound);
        else :
            $this->context->smarty->assign('usernotfound', '');
        endif;
        // Logout Successfully
        if (isset($this->context->cookie->logout_success)) :
            $this->context->smarty->assign('logout_success', "
            <div class='logout_success'>" . $this->context->cookie->logout_success . "</div>");
            unset($this->context->cookie->logout_success);
        else :
            $this->context->smarty->assign('logout_success', '');
        endif;
        // Project Created Message
        if (isset($this->context->cookie->project_created)) :
            $this->context->smarty->assign('project_created', "
            <div class='project_created'>" . $this->context->cookie->project_created . "</div>");
            unset($this->context->cookie->project_created);
        else :
            $this->context->smarty->assign('project_created', '');
        endif;
        // Something Went Wrong
        if (isset($this->context->cookie->project_error)) :
            $this->context->smarty->assign('project_error', "
            <div class='project_creating_not_allowed'>" . $this->context->cookie->project_error . "</div>");
            unset($this->context->cookie->project_error);
        else :
            $this->context->smarty->assign('project_error', '');
        endif;
        // Empty Value Message
        if (isset($this->context->cookie->project_creating_empty_values)) :
            $this->context->smarty->assign('project_creating_empty_values', "
            <div class='project_creating_empty_values'>
            " . $this->context->cookie->project_creating_empty_values . "</div>");
            unset($this->context->cookie->project_creating_empty_values);
        else :
            $this->context->smarty->assign('project_creating_empty_values', '');
        endif;
        // Empty value
        if (isset($this->context->cookie->empty_error)) :
            $this->context->smarty->assign('empty_error', "
            <div class='project_creating_not_allowed'>" . $this->context->cookie->empty_error . "</div>");
            unset($this->context->cookie->empty_error);
        else :
            $this->context->smarty->assign('empty_error', '');
        endif;
        // Error while not choose product Message
        if (isset($this->context->cookie->empty_error_products)) :
            $this->context->smarty->assign('empty_error_products', "
            <div class='project_creating_not_allowed'>" . $this->context->cookie->empty_error_products . "</div>");
            unset($this->context->cookie->empty_error_products);
        else :
            $this->context->smarty->assign('empty_error_products', '');
        endif;
        // Insufficient balance Message
        if (isset($this->context->cookie->balance_error)) :
            $this->context->smarty->assign('balance_error', "
            <div class='project_creating_not_allowed'>" . $this->context->cookie->balance_error . "</div>");
            unset($this->context->cookie->balance_error);
        else :
            $this->context->smarty->assign('balance_error', '');
        endif;
        // Something Went Wrong Xml
        if (isset($this->context->cookie->project_error_xml)) :
            $this->context->smarty->assign('project_error_xml', "
            <div class='project_creating_not_allowed'>" . $this->context->cookie->project_error_xml . "</div>");
            unset($this->context->cookie->project_error_xml);
        else :
            $this->context->smarty->assign('project_error_xml', '');
        endif;
        // Accepts Product
        if (isset($this->context->cookie->accept_products_success)) :
            $this->context->smarty->assign('accept_products_success', "
            <div class='project_created'>" . $this->context->cookie->accept_products_success . "</div>");
            unset($this->context->cookie->accept_products_success);
        else :
            $this->context->smarty->assign('accept_products_success', '');
        endif;
        // Products for review
        if (isset($this->context->cookie->product_for_review)) :
            $this->context->smarty->assign('product_for_review', "
            <div class='project_created'>" . $this->context->cookie->product_for_review . "</div>");
            unset($this->context->cookie->product_for_review);
        else :
            $this->context->smarty->assign('product_for_review', '');
        endif;
        // Accept Selected Products
        if (isset($this->context->cookie->accept_select_products)) :
            $this->context->smarty->assign('accept_select_products', "
            <div class='confirm_registration_msg'>" . $this->context->cookie->accept_select_products . "</div>");
            unset($this->context->cookie->accept_select_products);
        else :
            $this->context->smarty->assign('accept_select_products', '');
        endif;
        // Lanuage Error Xml
        if (isset($this->context->cookie->lang_error_xml)) :
            $this->context->smarty->assign('lang_error_xml', "
            <div class='lang_error_msg'>" . $this->context->cookie->lang_error_xml . "</div>");
            unset($this->context->cookie->lang_error_xml);
        else :
            $this->context->smarty->assign('lang_error_xml', '');
        endif;
        return $this->display(dirname(__FILE__), '/views/templates/hook/account.tpl');
    }
    
    /**
     * Get the action submited from the configuration page
     * @return string
     */
    protected function getPostSubmitValue()
    {
        if (Tools::getValue('signup') == 'Registrati') {
            foreach (self::$signup_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        if (Tools::getValue('login') == 'Accesso') {
            foreach (self::$login_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        if (Tools::getValue('logout') == 'Disconnettersi') {
            foreach (self::$logout_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        if (Tools::getValue('createproject') == 'Invia') {
            foreach (self::$createproject_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('editproject') == 'Submit') {
            foreach (self::$editproject_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('activation') == 'Attivare ora') {
            foreach (self::$activation_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('get_quote') == 'Ottieni Preventivo') {
            foreach (self::$getquote_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('direct_create_order') == 'Crea Ordine') {
            foreach (self::$createorder_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('import_xml') == 'Importa ora') {
            foreach (self::$importxml_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('xml_products') == 'Accettare') {
            foreach (self::$completexmlproducts_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    $value = 'accept';
                    return $value;
                }
            }
        }
        
        if (Tools::getValue('xml_products') == 'Chiedi una revisione') {
            foreach (self::$reviewxmlproducts_post_submit_values as $value) {
                if (Tools::isSubmit($value)) {
                    return 'review';
                }
            }
        }
        
        return false;
    }
    
    /**
     * Determins if on the module configuration page
     * @return bool
     */
    public function isConfigPage()
    {
        return self::isAdminPage('modules') && Tools::getValue('configure') === $this->name;
    }
    
    /**
     * Determines if on the specified admin page
     * @param string $page
     * @return bool
     */
    public static function isAdminPage($page)
    {
        return Tools::getValue('controller') === 'Admin' . Tools::ucfirst($page);
    }
    
    private function redirectPage($msg = '', $type = 'SUCCESS', $tab = 'account', $project = '', $words = '')
    {
        $this->context->cookie->display_message      = $msg;
        $this->context->cookie->display_message_type = $type;
        $this->context->cookie->write();
        
        $port   = ($_SERVER['SERVER_PORT'] == '80') ? '' : (':' . $_SERVER['SERVER_PORT']);
        $domain = Tools::getShopDomainSsl(true);
        $rUri   = $_SERVER['REQUEST_URI'];
        if ($tab != 'listproducts' && $tab != 'reviewquote' && $tab != 'importxmlfile') {
            Tools::redirect($domain . $port . $rUri . '&tab=' . $tab);
        } elseif ($tab == 'reviewquote') {
            Tools::redirect($domain . $port . $rUri . '&tab=' . $tab . '&project=' . $project . '&words=' . $words);
        } elseif ($tab == 'importxmlfile') {
            Tools::redirect($domain . $port . $rUri . '&tab=' . $tab . '&review_id=' . $project);
        } else {
            Tools::redirect($domain . $port . $rUri . '&tab=' . $tab . '&project=' . $project);
        }
        exit;
    }
}
